Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(114)

Unified Diff: tools/create_sdk.py

Issue 11145024: Revert back to creating a revision file in create_sdk (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/create_sdk.py
===================================================================
--- tools/create_sdk.py (revision 13649)
+++ tools/create_sdk.py (working copy)
@@ -323,10 +323,12 @@
# Copy dart2js.
CopyDart2Js(build_dir, SDK_tmp, version)
- # Write the 'version' file
- if version is not None:
- with open(os.path.join(SDK_tmp, 'version'), 'w') as f:
- f.write(version + '\n')
+ revision = utils.GetRevision()
+
+ # Write the 'revision' file
+ if revision is not None:
+ with open(os.path.join(SDK_tmp, 'revision'), 'w') as f:
+ f.write(revision + '\n')
f.close()
Copy(join(HOME, 'README.dart-sdk'), join(SDK_tmp, 'README'))
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698